==> api-0.21.0-sources.jar: io/strimzi/api/kafka/model/KafkaMirrorMaker2Fluent.java <==
package io.strimzi.api.kafka.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.strimzi.api.kafka.model.status.KafkaMirrorMaker2Status;
import io.strimzi.api.kafka.model.status.KafkaMirrorMaker2StatusBuilder;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.strimzi.api.kafka.model.status.KafkaMirrorMaker2StatusFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaMirrorMaker2Fluent<A extends KafkaMirrorMaker2Fluent<A>> extends Fluent<A>{


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(String arg1);
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(StringBuffer arg1);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public KafkaMirrorMaker2Spec getSpec();
    public KafkaMirrorMaker2Spec buildSpec();
    public A withSpec(KafkaMirrorMaker2Spec spec);
    public Boolean hasSpec();
    public KafkaMirrorMaker2Fluent.SpecNested<A> withNewSpec();
    public KafkaMirrorMaker2Fluent.SpecNested<A> withNewSpecLike(KafkaMirrorMaker2Spec item);
    public KafkaMirrorMaker2Fluent.SpecNested<A> editSpec();
    public KafkaMirrorMaker2Fluent.SpecNested<A> editOrNewSpec();
    public KafkaMirrorMaker2Fluent.SpecNested<A> editOrNewSpecLike(KafkaMirrorMaker2Spec item);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public KafkaMirrorMaker2Fluent.MetadataNested<A> withNewMetadata();
    public KafkaMirrorMaker2Fluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public KafkaMirrorMaker2Fluent.MetadataNested<A> editMetadata();
    public KafkaMirrorMaker2Fluent.MetadataNested<A> editOrNewMetadata();
    public KafkaMirrorMaker2Fluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public KafkaMirrorMaker2Status getStatus();
    public KafkaMirrorMaker2Status buildStatus();
    public A withStatus(KafkaMirrorMaker2Status status);
    public Boolean hasStatus();
    public KafkaMirrorMaker2Fluent.StatusNested<A> withNewStatus();
    public KafkaMirrorMaker2Fluent.StatusNested<A> withNewStatusLike(KafkaMirrorMaker2Status item);
    public KafkaMirrorMaker2Fluent.StatusNested<A> editStatus();
    public KafkaMirrorMaker2Fluent.StatusNested<A> editOrNewStatus();
    public KafkaMirrorMaker2Fluent.StatusNested<A> editOrNewStatusLike(KafkaMirrorMaker2Status item);

    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaMirrorMaker2SpecFluent<KafkaMirrorMaker2Fluent.SpecNested<N>>{

        
    public N and();    public N endSpec();
}
    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<KafkaMirrorMaker2Fluent.MetadataNested<N>>{

        
    public N and();    public N endMetadata();
}
    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaMirrorMaker2StatusFluent<KafkaMirrorMaker2Fluent.StatusNested<N>>{

        
    public N and();    public N endStatus();
}


}

==> api-0.23.0-sources.jar: io/strimzi/api/kafka/model/KafkaMirrorMaker2Fluent.java <==
package io.strimzi.api.kafka.model;

import io.fabric8.kubernetes.api.model.ObjectMeta;
import java.lang.StringBuilder;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import io.strimzi.api.kafka.model.status.KafkaMirrorMaker2Status;
import io.strimzi.api.kafka.model.status.KafkaMirrorMaker2StatusBuilder;
import java.lang.String;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.StringBuffer;
import io.fabric8.kubernetes.api.model.ObjectMetaFluent;
import io.strimzi.api.kafka.model.status.KafkaMirrorMaker2StatusFluent;
import java.lang.Deprecated;
import java.lang.Object;
import java.util.List;
import java.lang.Boolean;
import java.util.Map;

public interface KafkaMirrorMaker2Fluent<A extends KafkaMirrorMaker2Fluent<A>> extends Fluent<A> {


    public String getApiVersion();
    public A withApiVersion(String apiVersion);
    public Boolean hasApiVersion();
    public A withNewApiVersion(StringBuilder arg1);
    public A withNewApiVersion(int[] arg1,int arg2,int arg3);
    public A withNewApiVersion(char[] arg1);
    public A withNewApiVersion(StringBuffer arg1);
    public A withNewApiVersion(byte[] arg1,int arg2);
    public A withNewApiVersion(byte[] arg1);
    public A withNewApiVersion(char[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3);
    public A withNewApiVersion(byte[] arg1,int arg2,int arg3,int arg4);
    public A withNewApiVersion(String arg1);
    
/**
 * This method has been deprecated, please use method buildSpec instead.
 * @return The buildable object.
 */
@Deprecated public KafkaMirrorMaker2Spec getSpec();
    public KafkaMirrorMaker2Spec buildSpec();
    public A withSpec(KafkaMirrorMaker2Spec spec);
    public Boolean hasSpec();
    public KafkaMirrorMaker2Fluent.SpecNested<A> withNewSpec();
    public KafkaMirrorMaker2Fluent.SpecNested<A> withNewSpecLike(KafkaMirrorMaker2Spec item);
    public KafkaMirrorMaker2Fluent.SpecNested<A> editSpec();
    public KafkaMirrorMaker2Fluent.SpecNested<A> editOrNewSpec();
    public KafkaMirrorMaker2Fluent.SpecNested<A> editOrNewSpecLike(KafkaMirrorMaker2Spec item);
    
/**
 * This method has been deprecated, please use method buildMetadata instead.
 * @return The buildable object.
 */
@Deprecated public ObjectMeta getMetadata();
    public ObjectMeta buildMetadata();
    public A withMetadata(ObjectMeta metadata);
    public Boolean hasMetadata();
    public KafkaMirrorMaker2Fluent.MetadataNested<A> withNewMetadata();
    public KafkaMirrorMaker2Fluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
    public KafkaMirrorMaker2Fluent.MetadataNested<A> editMetadata();
    public KafkaMirrorMaker2Fluent.MetadataNested<A> editOrNewMetadata();
    public KafkaMirrorMaker2Fluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
    
/**
 * This method has been deprecated, please use method buildStatus instead.
 * @return The buildable object.
 */
@Deprecated public KafkaMirrorMaker2Status getStatus();
    public KafkaMirrorMaker2Status buildStatus();
    public A withStatus(KafkaMirrorMaker2Status status);
    public Boolean hasStatus();
    public KafkaMirrorMaker2Fluent.StatusNested<A> withNewStatus();
    public KafkaMirrorMaker2Fluent.StatusNested<A> withNewStatusLike(KafkaMirrorMaker2Status item);
    public KafkaMirrorMaker2Fluent.StatusNested<A> editStatus();
    public KafkaMirrorMaker2Fluent.StatusNested<A> editOrNewStatus();
    public KafkaMirrorMaker2Fluent.StatusNested<A> editOrNewStatusLike(KafkaMirrorMaker2Status item);
    public interface SpecNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaMirrorMaker2SpecFluent<KafkaMirrorMaker2Fluent.SpecNested<N>> {

            public N and();
            public N endSpec();    }


    public interface MetadataNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,ObjectMetaFluent<KafkaMirrorMaker2Fluent.MetadataNested<N>> {

            public N and();
            public N endMetadata();    }


    public interface StatusNested<N> extends io.fabric8.kubernetes.api.builder.Nested<N>,KafkaMirrorMaker2StatusFluent<KafkaMirrorMaker2Fluent.StatusNested<N>> {

            public N and();
            public N endStatus();    }


}
